        function getT(rr,cc){
       if(rr==6 && cc==0){return '<strong>Temperatura (C) y Altura Geopotencial (m) en 500 hPa</strong><br><br><strong>20260625 a 00</strong> UTC HH+204 (rango:192-216)<br><strong>control +<br>EPS</strong>';}
       if(rr==6 && cc==1){return '<strong>Temperatura (C) y Altura Geopotencial (m) en 500 hPa</strong><br><br><strong>20260625 a 00</strong> UTC HH+204 (rango:192-216)<br>grupo: <strong>1</strong> representante: <strong>37</strong> miembros: 15 <br>1,4,7,9,11,16,17,18,20,24,37,39,44,49,50';}
       if(rr==6 && cc==2){return '<strong>Temperatura (C) y Altura Geopotencial (m) en 500 hPa</strong><br><br><strong>20260625 a 00</strong> UTC HH+204 (rango:192-216)<br>grupo: <strong>2</strong> representante: <strong>23</strong> miembros: 14 <br>5,10,12,13,14,21,23,27,31,32,34,35,38,42';}
       if(rr==6 && cc==3){return '<strong>Temperatura (C) y Altura Geopotencial (m) en 500 hPa</strong><br><br><strong>20260625 a 00</strong> UTC HH+204 (rango:192-216)<br>grupo: <strong>3</strong> representante: <strong>15</strong> miembros: 10 <strong>control</strong><br>0,3,15,25,26,28,29,30,45,47';}
       if(rr==6 && cc==4){return '<strong>Temperatura (C) y Altura Geopotencial (m) en 500 hPa</strong><br><br><strong>20260625 a 00</strong> UTC HH+204 (rango:192-216)<br>grupo: <strong>4</strong> representante: <strong>41</strong> miembros: 6 <br>6,19,22,41,43,48';}
       if(rr==6 && cc==5){return '<strong>Temperatura (C) y Altura Geopotencial (m) en 500 hPa</strong><br><br><strong>20260625 a 00</strong> UTC HH+204 (rango:192-216)<br>grupo: <strong>5</strong> representante: <strong>8</strong> miembros: 6 <br>2,8,33,36,40,46';}
       if(rr==29 && cc==0){return '<strong>Probabilidad de racha maxima superior a 20 km/h (11 kt)</strong><br><br><strong>20260625 a 00</strong> UTC HH+204 (rango:192-216)<br><strong>control +<br>EPS</strong>';}
       if(rr==29 && cc==1){return '<strong>Probabilidad de racha maxima superior a 20 km/h (11 kt)</strong><br><br><strong>20260625 a 00</strong> UTC HH+204 (rango:192-216)<br>grupo: <strong>1</strong> representante: <strong>37</strong> miembros: 15 <br>1,4,7,9,11,16,17,18,20,24,37,39,44,49,50';}
       if(rr==29 && cc==2){return '<strong>Probabilidad de racha maxima superior a 20 km/h (11 kt)</strong><br><br><strong>20260625 a 00</strong> UTC HH+204 (rango:192-216)<br>grupo: <strong>2</strong> representante: <strong>23</strong> miembros: 14 <br>5,10,12,13,14,21,23,27,31,32,34,35,38,42';}
       if(rr==29 && cc==3){return '<strong>Probabilidad de racha maxima superior a 20 km/h (11 kt)</strong><br><br><strong>20260625 a 00</strong> UTC HH+204 (rango:192-216)<br>grupo: <strong>3</strong> representante: <strong>15</strong> miembros: 10 <strong>control</strong><br>0,3,15,25,26,28,29,30,45,47';}
       if(rr==29 && cc==4){return '<strong>Probabilidad de racha maxima superior a 20 km/h (11 kt)</strong><br><br><strong>20260625 a 00</strong> UTC HH+204 (rango:192-216)<br>grupo: <strong>4</strong> representante: <strong>41</strong> miembros: 6 <br>6,19,22,41,43,48';}
       if(rr==29 && cc==5){return '<strong>Probabilidad de racha maxima superior a 20 km/h (11 kt)</strong><br><br><strong>20260625 a 00</strong> UTC HH+204 (rango:192-216)<br>grupo: <strong>5</strong> representante: <strong>8</strong> miembros: 6 <br>2,8,33,36,40,46';}
       if(rr==30 && cc==0){return '<strong>Probabilidad de racha maxima superior a 40 km/h (22 kt)</strong><br><br><strong>20260625 a 00</strong> UTC HH+204 (rango:192-216)<br><strong>control +<br>EPS</strong>';}
       if(rr==30 && cc==1){return '<strong>Probabilidad de racha maxima superior a 40 km/h (22 kt)</strong><br><br><strong>20260625 a 00</strong> UTC HH+204 (rango:192-216)<br>grupo: <strong>1</strong> representante: <strong>37</strong> miembros: 15 <br>1,4,7,9,11,16,17,18,20,24,37,39,44,49,50';}
       if(rr==30 && cc==2){return '<strong>Probabilidad de racha maxima superior a 40 km/h (22 kt)</strong><br><br><strong>20260625 a 00</strong> UTC HH+204 (rango:192-216)<br>grupo: <strong>2</strong> representante: <strong>23</strong> miembros: 14 <br>5,10,12,13,14,21,23,27,31,32,34,35,38,42';}
       if(rr==30 && cc==3){return '<strong>Probabilidad de racha maxima superior a 40 km/h (22 kt)</strong><br><br><strong>20260625 a 00</strong> UTC HH+204 (rango:192-216)<br>grupo: <strong>3</strong> representante: <strong>15</strong> miembros: 10 <strong>control</strong><br>0,3,15,25,26,28,29,30,45,47';}
       if(rr==30 && cc==4){return '<strong>Probabilidad de racha maxima superior a 40 km/h (22 kt)</strong><br><br><strong>20260625 a 00</strong> UTC HH+204 (rango:192-216)<br>grupo: <strong>4</strong> representante: <strong>41</strong> miembros: 6 <br>6,19,22,41,43,48';}
       if(rr==30 && cc==5){return '<strong>Probabilidad de racha maxima superior a 40 km/h (22 kt)</strong><br><br><strong>20260625 a 00</strong> UTC HH+204 (rango:192-216)<br>grupo: <strong>5</strong> representante: <strong>8</strong> miembros: 6 <br>2,8,33,36,40,46';}
       if(rr==31 && cc==0){return '<strong>Probabilidad de racha maxima superior a 63 km/h (34 kt)</strong><br><br><strong>20260625 a 00</strong> UTC HH+204 (rango:192-216)<br><strong>control +<br>EPS</strong>';}
       if(rr==31 && cc==1){return '<strong>Probabilidad de racha maxima superior a 63 km/h (34 kt)</strong><br><br><strong>20260625 a 00</strong> UTC HH+204 (rango:192-216)<br>grupo: <strong>1</strong> representante: <strong>37</strong> miembros: 15 <br>1,4,7,9,11,16,17,18,20,24,37,39,44,49,50';}
       if(rr==31 && cc==2){return '<strong>Probabilidad de racha maxima superior a 63 km/h (34 kt)</strong><br><br><strong>20260625 a 00</strong> UTC HH+204 (rango:192-216)<br>grupo: <strong>2</strong> representante: <strong>23</strong> miembros: 14 <br>5,10,12,13,14,21,23,27,31,32,34,35,38,42';}
       if(rr==31 && cc==3){return '<strong>Probabilidad de racha maxima superior a 63 km/h (34 kt)</strong><br><br><strong>20260625 a 00</strong> UTC HH+204 (rango:192-216)<br>grupo: <strong>3</strong> representante: <strong>15</strong> miembros: 10 <strong>control</strong><br>0,3,15,25,26,28,29,30,45,47';}
       if(rr==31 && cc==4){return '<strong>Probabilidad de racha maxima superior a 63 km/h (34 kt)</strong><br><br><strong>20260625 a 00</strong> UTC HH+204 (rango:192-216)<br>grupo: <strong>4</strong> representante: <strong>41</strong> miembros: 6 <br>6,19,22,41,43,48';}
       if(rr==31 && cc==5){return '<strong>Probabilidad de racha maxima superior a 63 km/h (34 kt)</strong><br><br><strong>20260625 a 00</strong> UTC HH+204 (rango:192-216)<br>grupo: <strong>5</strong> representante: <strong>8</strong> miembros: 6 <br>2,8,33,36,40,46';}
       if(rr==32 && cc==0){return '<strong>Probabilidad de racha maxima superior a 90 km/h (48 kt)</strong><br><br><strong>20260625 a 00</strong> UTC HH+204 (rango:192-216)<br><strong>control +<br>EPS</strong>';}
       if(rr==32 && cc==1){return '<strong>Probabilidad de racha maxima superior a 90 km/h (48 kt)</strong><br><br><strong>20260625 a 00</strong> UTC HH+204 (rango:192-216)<br>grupo: <strong>1</strong> representante: <strong>37</strong> miembros: 15 <br>1,4,7,9,11,16,17,18,20,24,37,39,44,49,50';}
       if(rr==32 && cc==2){return '<strong>Probabilidad de racha maxima superior a 90 km/h (48 kt)</strong><br><br><strong>20260625 a 00</strong> UTC HH+204 (rango:192-216)<br>grupo: <strong>2</strong> representante: <strong>23</strong> miembros: 14 <br>5,10,12,13,14,21,23,27,31,32,34,35,38,42';}
       if(rr==32 && cc==3){return '<strong>Probabilidad de racha maxima superior a 90 km/h (48 kt)</strong><br><br><strong>20260625 a 00</strong> UTC HH+204 (rango:192-216)<br>grupo: <strong>3</strong> representante: <strong>15</strong> miembros: 10 <strong>control</strong><br>0,3,15,25,26,28,29,30,45,47';}
       if(rr==32 && cc==4){return '<strong>Probabilidad de racha maxima superior a 90 km/h (48 kt)</strong><br><br><strong>20260625 a 00</strong> UTC HH+204 (rango:192-216)<br>grupo: <strong>4</strong> representante: <strong>41</strong> miembros: 6 <br>6,19,22,41,43,48';}
       if(rr==32 && cc==5){return '<strong>Probabilidad de racha maxima superior a 90 km/h (48 kt)</strong><br><br><strong>20260625 a 00</strong> UTC HH+204 (rango:192-216)<br>grupo: <strong>5</strong> representante: <strong>8</strong> miembros: 6 <br>2,8,33,36,40,46';}
       if(rr==33 && cc==0){return '<strong>Probabilidad de racha maxima superior a 119 km/h (64 kt)</strong><br><br><strong>20260625 a 00</strong> UTC HH+204 (rango:192-216)<br><strong>control +<br>EPS</strong>';}
       if(rr==33 && cc==1){return '<strong>Probabilidad de racha maxima superior a 119 km/h (64 kt)</strong><br><br><strong>20260625 a 00</strong> UTC HH+204 (rango:192-216)<br>grupo: <strong>1</strong> representante: <strong>37</strong> miembros: 15 <br>1,4,7,9,11,16,17,18,20,24,37,39,44,49,50';}
       if(rr==33 && cc==2){return '<strong>Probabilidad de racha maxima superior a 119 km/h (64 kt)</strong><br><br><strong>20260625 a 00</strong> UTC HH+204 (rango:192-216)<br>grupo: <strong>2</strong> representante: <strong>23</strong> miembros: 14 <br>5,10,12,13,14,21,23,27,31,32,34,35,38,42';}
       if(rr==33 && cc==3){return '<strong>Probabilidad de racha maxima superior a 119 km/h (64 kt)</strong><br><br><strong>20260625 a 00</strong> UTC HH+204 (rango:192-216)<br>grupo: <strong>3</strong> representante: <strong>15</strong> miembros: 10 <strong>control</strong><br>0,3,15,25,26,28,29,30,45,47';}
       if(rr==33 && cc==4){return '<strong>Probabilidad de racha maxima superior a 119 km/h (64 kt)</strong><br><br><strong>20260625 a 00</strong> UTC HH+204 (rango:192-216)<br>grupo: <strong>4</strong> representante: <strong>41</strong> miembros: 6 <br>6,19,22,41,43,48';}
       if(rr==33 && cc==5){return '<strong>Probabilidad de racha maxima superior a 119 km/h (64 kt)</strong><br><br><strong>20260625 a 00</strong> UTC HH+204 (rango:192-216)<br>grupo: <strong>5</strong> representante: <strong>8</strong> miembros: 6 <br>2,8,33,36,40,46';}
}
